
# PySolverView

PySolverView is a wrapper for the optimization and root finding methods of Scipy.

## Features

- Print and visualize convergence history
- Streamlined problem definition (object-oriented)
- Improved function and gradient evaluation to avoid unnecesary model evaluations

## Documentation

Please refer to the [`documentation`](https://turbo-sim.github.io/pysolver_view/index.html) for:
- Installation instructions
- Tutorials showing how to use the code
- Complete documentation of all functions and classes in PySolverView


## Other info
- Pygmo and pygmo-plugin-nonfree should be installed with Conda
